habitat.sensors.stdtelem
========================

.. automodule:: habitat.sensors.stdtelem

   
   
   .. rubric:: Functions

   .. autosummary::
   
      coordinate
      strptime
      time
   
   

   
   
   

   
   
   